@@ -6,9 +6,13 @@ from .archive import (
     CenterPoint,
     Percent,
     Overlap,
+    License,
+    Band,
+    BundleOption,
     Seat,
     Price,
     SearchResult,
+    SearchResponse,
     SearchRequest,
     OrderRequest,
     ArchiveAPI
@@ -29,3 +33,7 @@ from .common import (
 from .exception import (
     ArlulaSessionError
 )
+
+from .util import (
+    parse_rfc3339
+)
